# This program is free software; you can redistribute it and/or modify it under
# the terms of the GNU General Public License as published by the Free Software
# Foundation; either version 2 of the License, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU General Public License for more details
#
# You should have received a copy of the GNU General Public License along with
# this program; if not, write to the Free Software Foundation, Inc.,
# 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

""" Copyright (c) 2007-2018 David Douard (Paris, FRANCE).
https://bitbucket.org/dddouard/pygpibtoolkit -- mailto:david.douard@sdfa3.org
"""

from setuptools import setup, find_packages

from codecs import open
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README'), encoding='utf-8') as f:
    long_description = f.read()


setup(name="pygpibtoolkit",
      description='A Python 3 toolkit for GPIB',
      long_description=long_description,
      long_description_content_type='text/x-rst',
      author='David Douard',
      author_email='david.douard@sdfa3.org',
      classifiers=[
          'Development Status :: 4 - Beta',
          'License :: OSI Approved :: GPL',
          'Programming Language :: Python :: 3',
      ],
      url='http://pygpibtoolkit.readthedocs.io/en/latest/',
      keywords='gpib hpib ieee-488',
      packages=find_packages(),
      version='0.1.0',
      install_requires=[
          'pyserial', 'numpy', 'PyQt5', 'pyqtgraph'],

      entry_points={
          'console_scripts': [
              'pygpib-detect=pygpibtoolkit.detect:main',
              'hp3562-coord=pygpibtoolkit.HP3562A.coord_decoder:main',
              'hp3562-state=pygpibtoolkit.HP3562A.state_decoder:main',
              'hp3562-trace=pygpibtoolkit.HP3562A.trace_decoder:main',
              'hp3562-dump=pygpibtoolkit.HP3562A.dump_datablock:main',
              'hp3562=pygpibtoolkit.HP3562A.q3562A:main',
              'pygpib-plotter=pygpibtoolkit.plotter.qgpib_plotter:main',
          ]},
      project_urls={
          'Bug Reports': 'https://bitbucket.org/dddouard/pygpibtoolkit/issues',
          'Source': 'https://bitbucket.org/dddouard/pygpibtoolkit/src',
      },
)
